<?php
/**
 * PHPPowerPoint
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category   PHPPowerPoint
 * @package    PHPPowerPoint_Shape
 * @copyright  Copyright (c) 2009 - 2010 PHPPowerPoint (http://www.codeplex.com/PHPPowerPoint)
 * @license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
 * @version    0.1.0, 2009-04-27
 */


/** PHPPowerPoint_Shape_RichText_ITextElement */
require_once 'PHPPowerPoint/Shape/RichText/ITextElement.php';

/** PHPPowerPoint_Shape_RichText_TextElement */
require_once 'PHPPowerPoint/Shape/RichText/TextElement.php';

/** PHPPowerPoint_Style_Font */
require_once 'PHPPowerPoint/Style/Font.php';


/**
 * PHPPowerPoint_Shape_RichText_Run
 *
 * @category   PHPPowerPoint
 * @package    PHPPowerPoint_Shape
 * @copyright  Copyright (c) 2009 - 2010 PHPPowerPoint (http://www.codeplex.com/PHPPowerPoint)
 */
class PHPPowerPoint_Shape_RichText_Run extends PHPPowerPoint_Shape_RichText_TextElement implements PHPPowerPoint_Shape_RichText_ITextElement
{	
	/**
	 * Font
	 *
	 * @var PHPPowerPoint_Style_Font
	 */
	private $_font;
	
    /**
     * Create a new PHPPowerPoint_Shape_RichText_Run instance
     *
     * @param 	string		$pText		Text
     */
    public function __construct($pText = '')
    {
    	// Initialise variables
    	$this->setText($pText);
    	$this->_font = new PHPPowerPoint_Style_Font();
    }
	
	/**
	 * Get font
	 *
	 * @return PHPPowerPoint_Style_Font
	 */	
	public function getFont() {
		return $this->_font;
	}
	
	/**
	 * Set font
	 *
	 * @param	PHPPowerPoint_Style_Font		$pFont		Font
	 * @throws 	Exception
	 */	
	public function setFont(PHPPowerPoint_Style_Font $pFont = null) {
		$this->_font = $pFont;
	}
	
	/**
	 * Get hash code
	 *
	 * @return string	Hash code
	 */	
	public function getHashCode() {
    	return md5(
    		  $this->getText()
    		. $this->_font->getHashCode()
    		. __CLASS__
    	);
    }
	    
	/**
	 * Implement PHP __clone to create a deep clone, not just a shallow copy.
	 */
	public function __clone() {
		$vars = get_object_vars($this);
		foreach ($vars as $key => $value) {
			if (is_object($value)) {
				$this->$key = clone $value;
			} else {
				$this->$key = $value;
			}
		}
	}
}
